@@ -6,8 +6,9 @@
 #'
 #' @references The data was compiled by Erik Steiner and Jason Heppler at the
 #'   Center for Spatial and Textual Analysis, Stanford University. See their
-#'   \href{https://github.com/cestastanford/historical-us-city-populations}{description
-#'    of the data} for a fuller accounting of how the data was gathered.
+#'   \href{https://github.com/cestastanford/historical-us-city-populations}{the
+#'   description of the data} for a fuller accounting of how the data was
+#'   gathered.
 #'
 #' @param map_date If \code{NULL}, then city populations from the 2010 census
 #'   (the most recent census) are returned. This parameter accepts a \code{Date}
@@ -21,26 +22,31 @@
 #'   returned. If \code{NULL}, all boundaries will be returned.
 #'
 #' @examples
-#' if (require(USAboundariesData)) {
+#' if (require(USAboundariesData, quietly = TRUE)) {
 #'   us_cities(1805)
 #'   us_cities("1828-05-08")
 #'   us_cities()
 #' }
 #'
 #' @export
+#' @returns An \code{sf} object.
 us_cities <- function(map_date = NULL, states = NULL) {
+  # TODO maybe return all the cities to see trend over time?
   if (is.null(map_date)) {
     message("City populations for contemporary data come from the 2010 census.")
     map_date <- 2010
   }
-  if (is.character(map_date)) { map_date <- as.Date(map_date) }
+  if (is.character(map_date)) {
+    map_date <- as.Date(map_date)
+  }
   if (identical(class(map_date), "Date")) {
     map_date <- as.numeric(format(map_date, "%Y"))
   }
   stopifnot(is.numeric(map_date) && 1790 <= map_date && map_date <= 2010)
-  map_date <- trunc(map_date / 10 ) * 10
+  map_date <- trunc(map_date / 10) * 10
   check_data_package()
   cities <- USAboundariesData::census_cities
   cities <- filter_by_states(cities, states)
-  cities[cities$year == map_date & cities$population > 0, ]
+  cities <- cities[cities$year == map_date & cities$population > 0, ]
+  return(cities)
 }
