@@ -1,6 +1,6 @@
 #' Congressional district boundaries (contemporary)
 #'
-#' Get the current (2020) boundaries for U.S. Congressional districts.
+#' Get the current (2024) boundaries for U.S. Congressional districts.
 #'
 #' @param resolution The resolution of the boundaries.
 #' @param states A character vector of state or territory names. Only boundaries
@@ -14,16 +14,16 @@
 #'   \code{census_boundaries} help file in the USAboundariesData package.
 #'
 #' @examples
-#' if (require(USAboundariesData) && require(sf)) {
+#' if (require(USAboundariesData, quietly = TRUE) && require(sf, quietly = TRUE)) {
 #'   us_congressional <- us_congressional()
-#'   va_congressional <- us_congressional(states = "Virginia", resolution = "high")
+#'   va_congressional <- us_congressional(
+#'     states = "Virginia", resolution = "high")
 #'   plot(st_geometry(us_congressional))
 #'   plot(st_geometry(va_congressional))
 #' }
 #'
 #' @export
-us_congressional <- function(resolution = c("low", "high"),
-                             states = NULL) {
+us_congressional <- function(resolution = c("low", "high"), states = NULL) {
   resolution <- match.arg(resolution)
   check_data_package()
   if (resolution == "low") {
